#include "testlib.h"

#include <iostream>
#include <algorithm>
#include <utility>
#include <tuple>
#include <cassert>
#include <set>

using namespace std;

// Generate pair of non-equal integers in [l; r]
pair<int, int> gen_pair(int l, int r) {
    assert(r - l > 0);
    pair<int, int> ret;
    do {
        ret = make_pair(rnd.next(l, r), rnd.next(l, r));
    } while (ret.first == ret.second);
    return ret;
}

vector<pair<int, int> > gen_queries(int n, int m) {
    if (1ll * n * (n - 1) / 2 > 2 * m) {
        vector<pair<int, int> > vec;
        set<pair<int, int> > s;
        while ((int)vec.size() < m) {
            pair<int, int> p;
            do {
                p = gen_pair(1, n);
            } while (s.count(p) || s.count(make_pair(p.second, p.first)));
            vec.push_back(p);
            s.insert(p);
        }
        return vec;
    } else {
        vector<pair<int, int> > vec;
        for (int i = 1; i <= n; i++)
            for (int j = i + 1; j <= n; j++)
                vec.push_back(make_pair(i, j));
        shuffle(vec.begin(), vec.end());
        vec.resize(m);
        vec.shrink_to_fit();
        return vec;
    }
}

int main(int argc, char *argv[]) {
    registerGen(argc, argv, 1);

    int n = atoi(argv[1]);
    int m = atoi(argv[2]);

    vector<int> vec(n);
    for (int i = 0; i < n; i++)
        vec[i] = i;
    shuffle(vec.begin(), vec.end());

    cout << n << " " << m << endl;
    for (auto p : gen_queries(n, m)) {
        if (vec[p.first - 1] > vec[p.second - 1])
            swap(p.first, p.second);
        cout << p.first << " " << p.second << endl;
    }
    return 0;
}
